@@ -3,7 +3,7 @@
 """
 @author: Jiawei Wu
 @create time: 2020-04-05 19:44
-@edit time: 2020-04-06 15:39
+@edit time: 2020-05-10 22:15
 @FilePath: /vvlab/utils/__init__.py
 @desc: init method of utils
 """
@@ -12,5 +12,6 @@
 from .config import CUDA
 from .OUProcess import OUProcess
 from .ReplayBuffer import ReplayBuffer
+from .update import soft_update
 
-__all__ = ['CUDA', 'OUPrecess', 'ReplayBuffer']
\ No newline at end of file
+__all__ = ['CUDA', 'OUPrecess', 'ReplayBuffer', 'soft_update']
\ No newline at end of file
